@@ -2,13 +2,12 @@ package Class::Usul::TraitFor::UntaintedGetopts;
 
 use namespace::autoclean;
 
-use Class::Usul::Constants qw( FAILED NUL TRUE );
+use Class::Usul::Constants qw( FAILED NUL QUOTED_RE TRUE );
 use Class::Usul::Functions qw( emit_err untaint_cmdline );
 use Class::Usul::Getopt    qw( describe_options );
 use Data::Record;
 use Encode                 qw( decode );
 use JSON::MaybeXS          qw( decode_json );
-use Regexp::Common;
 use Scalar::Util           qw( blessed );
 use Moo::Role;
 
@@ -106,7 +105,7 @@ my $_build_options = sub {
       push @options, [ $_option_specification->( $name, $option ), $doc, $cfg ];
       defined $option->{autosplit} or next;
       $splitters->{ $name } = Data::Record->new( {
-         split => $option->{autosplit}, unless => $RE{quoted} } );
+         split => $option->{autosplit}, unless => QUOTED_RE } );
       $option->{short}
          and $splitters->{ $option->{short} } = $splitters->{ $name };
    }
@@ -259,8 +258,6 @@ None
 
 =item L<Moo::Role>
 
-=item L<Regexp::Common>
-
 =back
 
 =head1 Incompatibilities
@@ -283,7 +280,7 @@ Peter Flanigan, C<< <pjfl@cpan.org> >>
 
 =head1 License and Copyright
 
-Copyright (c) 2015 Peter Flanigan. All rights reserved
+Copyright (c) 2016 Peter Flanigan. All rights reserved
 
 This program is free software; you can redistribute it and/or modify it
 under the same terms as Perl itself. See L<perlartistic>
